mailr10135 - /branches/multi_processor_merge/multi/processor.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on January 07, 2010 - 16:51:
Author: bugman
Date: Thu Jan  7 16:51:15 2010
New Revision: 10135

URL: http://svn.gna.org/viewcvs/relax?rev=10135&view=rev
Log:
Added more sanity to the STDOUT and STDERR handling by adding some flushing.


Modified:
    branches/multi_processor_merge/multi/processor.py

Modified: branches/multi_processor_merge/multi/processor.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/multi_processor_merge/multi/processor.py?rev=10135&r1=10134&r2=10135&view=diff
==============================================================================
--- branches/multi_processor_merge/multi/processor.py (original)
+++ branches/multi_processor_merge/multi/processor.py Thu Jan  7 16:51:15 2010
@@ -749,7 +749,11 @@
         @note:  sys.stdout and sys.stderr are replaced with sys.__stdout__ 
ans sys.__stderr__.
         '''
 
-        # Restore the IO streams.
+        # First flush.
+        sys.stdout.flush()
+        sys.stderr.flush()
+
+        # Then restore the IO streams.
         sys.stdout = self.orig_stdout
         sys.stderr = self.orig_stderr
 




Related Messages


Powered by MHonArc, Updated Thu Jan 07 17:00:02 2010